@@ -42,7 +42,7 @@ typedef uint32_t char32_t;
 #endif
 #endif
 
-#define COURIER_UNICODE_VERSION 2002003
+#define COURIER_UNICODE_VERSION 2002004
 
 /*
 ** The system default character set, from the locale.
@@ -1112,7 +1112,7 @@ unicode_convert_tocbuf_fromutf8_init(const char *dst_chset,
 ** Convert a character string to UTF-8.
 **
 ** Returns a malloc-ed buffer holding the UTF-8 string, or NULL if an
-** error occured.
+** error occurred.
 */
 char *unicode_convert_toutf8(/* Text to convert to UTF-8 */
 			       const char *text,
@@ -1123,7 +1123,7 @@ char *unicode_convert_toutf8(/* Text to convert to UTF-8 */
 			       /*
 			       ** If non-NULL, and a non-NULL pointer is
 			       ** returned, *error is set to non-zero if
-			       ** a character conversion error has occured.
+			       ** a character conversion error has occurred.
 			       */
 			       int *error);
 
@@ -1131,7 +1131,7 @@ char *unicode_convert_toutf8(/* Text to convert to UTF-8 */
 ** Convert UTF-8 text to another character set.
 **
 ** Returns a malloc-ed buffer holding the string converted to the specified
-** character set, or NULL if an error occured.
+** character set, or NULL if an error occurred.
 */
 
 char *unicode_convert_fromutf8(/* A UTF-8 string */
@@ -1147,7 +1147,7 @@ char *unicode_convert_fromutf8(/* A UTF-8 string */
 				 /*
 				 ** If non-NULL, and a non-NULL pointer is
 				 ** returned, *error is set to non-zero if
-				 ** a character conversion error has occured.
+				 ** a character conversion error has occurred.
 				 */
 				 int *error);
 
@@ -1156,7 +1156,7 @@ char *unicode_convert_fromutf8(/* A UTF-8 string */
 ** buffer.
 **
 ** Returns a malloc-ed buffer holding the string converted to the specified
-** character set, or NULL if an error occured.
+** character set, or NULL if an error occurred.
 */
 
 char *unicode_convert_tobuf(/* A string to convert */
@@ -1176,7 +1176,7 @@ char *unicode_convert_tobuf(/* A string to convert */
 			      /*
 			      ** If non-NULL, and a non-NULL pointer is
 			      ** returned, *error is set to non-zero if
-			      ** a character conversion error has occured.
+			      ** a character conversion error has occurred.
 			      */
 			      int *error);
 
@@ -1574,7 +1574,7 @@ class iconvert::tou : public iconvert {
 
 	using iconvert::operator();
  private:
-	int converted(const char *ptr, size_t cnt);
+	int converted(const char *ptr, size_t cnt) override;
 
  public:
 	template<typename iter_t> class to_iter_class;
@@ -1625,7 +1625,7 @@ class iconvert::tou::to_iter_class : public iconvert::tou {
 	operator iter_t() const { return iter; }
 
  private:
-	int converted(const char32_t *ptr, size_t cnt)
+	int converted(const char32_t *ptr, size_t cnt) override
 	{
 		while (cnt)
 		{
@@ -1727,7 +1727,7 @@ class iconvert::fromu::to_iter_class : public iconvert::fromu {
 	operator iter_t() const { return iter; }
 
  private:
-	int converted(const char *ptr, size_t cnt)
+	int converted(const char *ptr, size_t cnt) override
 	{
 		while (cnt)
 		{
@@ -1853,7 +1853,7 @@ public:
 	using linebreak_callback_base::operator<<;
 	using linebreak_callback_base::operator();
 private:
-	int callback(int value);
+	int callback(int value) override;
 };
 
 /*
@@ -1861,9 +1861,15 @@ private:
 ** an input iterator sequence over linebreak values.
 */
 
-template<typename input_t> class linebreak_iter
-	: public std::iterator<std::input_iterator_tag, int, void>
-{
+template<typename input_t> class linebreak_iter {
+
+public:
+	typedef std::input_iterator_tag        iterator_category;
+	typedef int                            value_type;
+	typedef void                           difference_type;
+	typedef value_type *                   pointer;
+	typedef value_type &                   reference;
+private:
 	mutable input_t iter_value, end_iter_value;
 
 	mutable linebreak_callback_save_buf *buf;
@@ -2043,7 +2049,7 @@ public:
 	using linebreakc_callback_base::operator<<;
 	using linebreakc_callback_base::operator();
 private:
-	int callback(int, char32_t);
+	int callback(int, char32_t) override;
 };
 
 
@@ -2054,10 +2060,16 @@ private:
 ** the character.
 */
 
-template<typename input_t> class linebreakc_iter
-	: public std::iterator<std::input_iterator_tag,
-			       std::pair<int, char32_t>, void>
-{
+template<typename input_t> class linebreakc_iter {
+
+public:
+	typedef std::input_iterator_tag        iterator_category;
+	typedef std::pair<int, char32_t>       value_type;
+	typedef void                           difference_type;
+	typedef value_type *                   pointer;
+	typedef value_type &                   reference;
+private:
+
 	mutable input_t iter_value, end_iter_value;
 
 	mutable linebreakc_callback_save_buf *buf;
